@@ -29,6 +29,7 @@
 #include "eckit/config/LibEcKit.h"
 #include "eckit/config/Resource.h"
 #include "eckit/filesystem/BasePathNameT.h"
+#include "eckit/filesystem/PathName.h"
 #include "eckit/filesystem/PathNameFactory.h"
 #include "eckit/filesystem/StdDir.h"
 #include "eckit/io/FileHandle.h"
@@ -149,6 +150,9 @@ static void init() {
 
 //----------------------------------------------------------------------------------------------------------------------
 
+LocalPathName::LocalPathName(const PathName& path) :
+    LocalPathName(path.path(), false, true) {}
+
 LocalPathName LocalPathName::baseName(bool ext) const {
     const char* q = path_.c_str();
     int n         = -1;
@@ -415,6 +419,18 @@ void operator>>(Stream& s, LocalPathName& path) {
     s >> path.path_;
 }
 
+LocalPathName operator/(const LocalPathName& p1, const LocalPathName& p2) {
+    bool tildeIsUserHome = false;
+    bool skipTildeExpansion = true;
+    return eckit::LocalPathName(p1.path() + "/" + p2.path(), tildeIsUserHome, skipTildeExpansion);
+}
+
+LocalPathName operator/(const LocalPathName& p1, const char* p2) {
+    bool tildeIsUserHome = false;
+    bool skipTildeExpansion = true;
+    return eckit::LocalPathName(p1.path() + "/" + p2, tildeIsUserHome, skipTildeExpansion);
+}
+
 LocalPathName LocalPathName::fullName() const {
     if (path_.length() > 0 && path_[0] != '/') {
         char buf[PATH_MAX];
